==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/help/bug_admin_report_list.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bug_admin_report_list.php,v 1.6 2004/03/13 18:22:05 yeupou Exp $
#
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

help_header("Bug Administration -  Bug Reports List");

?>


<p>The Bug Tracking System allows you to define your own bug
reports that you or your team can use to search your project bug
database. For each report you can specify a set of of bug fields to
use as search criteria as well as those bug fields that must be
displayed in the result table.

<p>Project Administrators can define project-wide bug reports that are
usable by all team members whereas other users can only define and
modify their own reports.

Information displayed on this page:

<ul type="compact">

<li><b>ID:</b> a number that uniquely identify the bug report

<li><b>Name:</b> the report short name as it will appear in the report
select box when you'll be using the bug browsing screen.

<li><b>Description:</b> a description of your report (e.g. Simple
Report, 'QA report'...)

<li><b>Scope:</b>
<ul>

  <li><i><u>Project</u></i> : this report will be usable by all
  project members. Only project administrators can define project-wide
  reports.
  
  <li><i><u>Personal</u></i> : this report will be usable by its creator only.
</ul>
<p>

<li><b>Delete?:</b> click the trash icon to delete the
report. Project-wide reports can only be deleted by project
administrators
<ul>

==> savane-1.1.tar.gz: savane-1.1/frontend/php/help/bug_admin_report_list.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bug_admin_report_list.php,v 1.7 2005/06/30 17:19:34 toddy Exp $
#
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


require "../include/pre.php";

help_header("Bug Administration -  Bug Reports List");

?>


<p>The Bug Tracking System allows you to define your own bug
reports that you or your team can use to search your project bug
database. For each report you can specify a set of of bug fields to
use as search criteria as well as those bug fields that must be
displayed in the result table.

<p>Project Administrators can define project-wide bug reports that are
usable by all team members whereas other users can only define and
modify their own reports.

Information displayed on this page:

<ul type="compact">

<li><b>ID:</b> a number that uniquely identify the bug report

<li><b>Name:</b> the report short name as it will appear in the report
select box when you'll be using the bug browsing screen.

<li><b>Description:</b> a description of your report (e.g. Simple
Report, 'QA report'...)

<li><b>Scope:</b>
<ul>

  <li><i><u>Project</u></i> : this report will be usable by all
  project members. Only project administrators can define project-wide
  reports.
  
  <li><i><u>Personal</u></i> : this report will be usable by its creator only.
</ul>
<p>

<li><b>Delete?:</b> click the trash icon to delete the
report. Project-wide reports can only be deleted by project
administrators
<ul>
